meta_package_manager.managers.gem module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.managers.gem module

class `meta_package_manager.managers.gem.` `Gem`

  Bases: `meta_package_manager.base.PackageManager`

  `HOMEBREW_PATH` = u'/usr/local/bin/gem'
  `SYSTEM_PATH` = u'/usr/bin/gem'
  `platforms` = frozenset([u'macos'])
  `get_version`()

    Fetch version from `gem --version` output.

  `cli_path`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `name` = u'Ruby Gems'
  `installed`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `outdated`

    The `cachedproperty` is used similar to `property`, except that the wrapped method is only called once. This is commonly used to implement lazy attributes.

    After the property has been accessed, the value is stored on the instance itself, using the same name as the cachedproperty. This allows the cache to be cleared with `delattr()`, or through manipulating the object’s `__dict__`.

  `upgrade_cli`(package_id=None)
  `upgrade_all_cli`()